@@ -8,7 +8,7 @@ def set_to_output(address):
     RPIO.setup(address, RPIO.OUT)
 
 
-def switch(address, value):
+def pl_switch(address, value):
     if value not in ["on", "off"]:
         raise ValueError("Switch value must be 'on' or 'off'")
 
@@ -20,18 +20,18 @@ def switch(address, value):
     RPIO.output(address, value == "on")
 
 
-def all_on():
+def pl_all_lights_on():
     for pin in USED_GPIO_LIST:
         try:
-            switch(pin, "on")
+            pl_switch(pin, "on")
         except WrongGPIOConfiguration:
             continue
 
 
-def all_off():
+def pl_all_lights_off():
     for pin in USED_GPIO_LIST:
         try:
-            switch(pin, "off")
+            pl_switch(pin, "off")
         except WrongGPIOConfiguration:
             continue
 
